/**********************************************************************************************
    Copyright (C) 2018 Oliver Eichler <oliver.eichler@gmx.de>

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.

**********************************************************************************************/

#ifndef CHELPSEARCH_H
#define CHELPSEARCH_H

#include <QWidget>

class QLabel;
class QHelpEngine;
class QHelpSearchEngine;
class QHelpSearchQueryWidget;
class QHelpSearchResultWidget;

class CHelpSearch : public QWidget {
  Q_OBJECT
 public:
  CHelpSearch(QHelpEngine* engine, QWidget* parent);
  virtual ~CHelpSearch() = default;

 private slots:
  void slotSearch();

 private:
  QLabel* labelSearch;
  QHelpSearchEngine* searchEngine;
  QHelpSearchQueryWidget* query;
  QHelpSearchResultWidget* result;
};

#endif  // CHELPSEARCH_H
